==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/admin/messages/sq/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Statusi <strong>Cronjob</strong>',
    '<strong>Queue</strong> Status' => 'Statusi <strong>Queue</strong>',
    'About HumHub' => 'Rreth HumHub',
    'Background Jobs' => 'Punët në prapaskenë',
    'Checking HumHub software prerequisites.' => 'Kontrollimi i parakushteve të softuerit HumHub.',
    'Database' => 'Baza e të dhënave',
    'Database migration results:' => 'Rezultati i migrimit të bazës së të dhënave',
    'Delayed' => 'I vonuar',
    'Displaying {count} entries per page.' => 'Duke shfaqur {count} hyrje për faqe.',
    'Done' => 'E kryer',
    'Driver' => 'Driver',
    'Error' => 'Gabim',
    'Flush entries' => 'Hyrjet e ndezura',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub është momentalisht në mundësinë e korigjimit (debug mode). Çaktivizojeni kur uebsajti futet në funksion!',
    'Info' => 'Informata',
    'Last run (daily):' => 'Aktivizimi i fundit (ditorë):',
    'Last run (hourly):' => 'Aktivizimi i fundit (çdo orë)',
    'Licences' => 'Licensat',
    'Logging' => 'Logging',
    'Never' => 'Kurrë',
    'Other' => 'Tjera',
    'Permissions' => 'Lejet',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Ju lutemi referojuni dokumentacionit për të konfiguruar cronjobs dhe queue.',
    'Prerequisites' => 'Parakushtet',
    'Queue successfully cleared.' => 'Queue është pastruar me sukses.',
    'Re-Run tests' => 'Riaktivizo testet',
    'Reserved' => 'E rezervuar',
    'Search index rebuild in progress.' => 'Rindërtimi i indeksit të kërkimit në progres.',
    'Search term...' => 'Kërko termin...',
    'See installation manual for more details.' => 'Shikoni manualin e instalimit për më tepër detaje.',
    'Select category..' => 'Selekto kategorinë',
    'Select day' => 'Selekto ditën',
    'Select level...' => 'Selekto nivelin...',
    'Settings' => 'Cilësimet',
    'The current main HumHub database name is ' => 'Emri i tanishëm i bazës së të dhënave të HumHub është',
    'There is a new update available! (Latest version: %version%)' => 'Ka një përditësim të ri! (Vezioni i fundit: (%version%)',
    'This HumHub installation is up to date!' => 'Ky instalim i HumHub është i përditësuar!',
    'Total {count} entries found.' => 'Total {count} hyrje u gjetën.',
    'Trace' => 'Gjurmo',
    'Waiting' => 'Duke pritur',
    'Warning' => 'Paralajmërim',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Base URL' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/sq/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Statusi <strong>Cronjob</strong>',
    '<strong>Queue</strong> Status' => 'Statusi <strong>Queue</strong>',
    'About HumHub' => 'Rreth HumHub',
    'Background Jobs' => 'Punët në prapaskenë',
    'Checking HumHub software prerequisites.' => 'Kontrollimi i parakushteve të softuerit HumHub.',
    'Database' => 'Baza e të dhënave',
    'Database migration results:' => 'Rezultati i migrimit të bazës së të dhënave',
    'Delayed' => 'I vonuar',
    'Displaying {count} entries per page.' => 'Duke shfaqur {count} hyrje për faqe.',
    'Done' => 'E kryer',
    'Driver' => 'Driver',
    'Error' => 'Gabim',
    'Flush entries' => 'Hyrjet e ndezura',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub është momentalisht në mundësinë e korigjimit (debug mode). Çaktivizojeni kur uebsajti futet në funksion!',
    'Info' => 'Informata',
    'Last run (daily):' => 'Aktivizimi i fundit (ditorë):',
    'Last run (hourly):' => 'Aktivizimi i fundit (çdo orë)',
    'Licences' => 'Licensat',
    'Logging' => 'Logging',
    'Never' => 'Kurrë',
    'Other' => 'Tjera',
    'Permissions' => 'Lejet',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Ju lutemi referojuni dokumentacionit për të konfiguruar cronjobs dhe queue.',
    'Prerequisites' => 'Parakushtet',
    'Queue successfully cleared.' => 'Queue është pastruar me sukses.',
    'Re-Run tests' => 'Riaktivizo testet',
    'Reserved' => 'E rezervuar',
    'Search index rebuild in progress.' => 'Rindërtimi i indeksit të kërkimit në progres.',
    'Search term...' => 'Kërko termin...',
    'See installation manual for more details.' => 'Shikoni manualin e instalimit për më tepër detaje.',
    'Select category..' => 'Selekto kategorinë',
    'Select day' => 'Selekto ditën',
    'Select level...' => 'Selekto nivelin...',
    'Settings' => 'Cilësimet',
    'The current main HumHub database name is ' => 'Emri i tanishëm i bazës së të dhënave të HumHub është',
    'There is a new update available! (Latest version: %version%)' => 'Ka një përditësim të ri! (Vezioni i fundit: (%version%)',
    'This HumHub installation is up to date!' => 'Ky instalim i HumHub është i përditësuar!',
    'Total {count} entries found.' => 'Total {count} hyrje u gjetën.',
    'Trace' => 'Gjurmo',
    'Waiting' => 'Duke pritur',
    'Warning' => 'Paralajmërim',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Base URL' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
